{% comment%}
    include from template:
        "django-for-runners/for_runners/templates/admin/for_runners/gpxmodel/leaflet_map.html"
{% endcomment %}

#map .leaflet-marker-start, #map .leaflet-marker-kilometers, #map .leaflet-marker-finish {
    font-weight: bold;
    color: white;
    font-size: 0.9em;
    border: 1.5px solid white;
    border-radius: 1em;
    line-height: 1.5em;
    text-align: center;
    vertical-align: middle;
}
#map .leaflet-marker-start {
    background-color: green;
}
#map .leaflet-marker-kilometers {
    background-color: blue;
}
#map .leaflet-marker-finish {
    background-color: red;
}
