# Generated by Django 2.1.8 on 2019-04-02 15:31

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('for_runners', '0007_auto_20190402_1628'),
    ]

    operations = [
        migrations.AlterField(
            model_name='gpxmodel',
            name='participation',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='track', to='for_runners.ParticipationModel'),
        ),
        migrations.AlterField(
            model_name='gpxmodel',
            name='tracked_by',
            field=models.ForeignKey(default=1, editable=False, help_text='The user that tracked this gpx entry', on_delete=django.db.models.deletion.PROTECT, related_name='gpxmodel_createby', to=settings.AUTH_USER_MODEL),
            preserve_default=False,
        ),
    ]
