{% load i18n  %}

<table>
    <tr>
        <th>{% trans "Track" %}</th>
        <th>{% trans "Length" %}</th>
        <th>{% trans "Avg. Pace" %}</th>
        <th>{% trans "Point count" %}</th>
        <th>{% trans "Avg. distance *" %}</th>
        <th>{% trans "creator" %}</th>
    </tr>
    {% for track in tracks %}
    <tr>
        <td>{{ track }}</td>
        <td>{{ track.human_length }}</td>
        <td>{{ track.human_pace }}</td>
        <td>{{ track.points_no }} points</td>
        <td>{{ track.point_density|stringformat:".1f" }} {% trans "Meter/Point" %}</td>
        <td>{{ track.creator }}</td>
    </tr>
    {% endfor %}
</table>
<p>* {% trans "Average distance in meters between two points." %}</p>