{% extends "admin/for_runners/change_list.html" %}
{% load i18n admin_urls %}

{% block object-tools %}
    <ul class="object-tools">
    {% block object-tools-items %}
        <li><a href="upload/">Upload GPX file</a></li>
        {% include "admin/import_export/change_list_export_item.html" %}{# <- add "export" link #}
        {# Don't call "block.super" to remove the "add item" link #}
    {% endblock %}
    </ul>
    {{ cl.statistics }}
{% endblock %}
