# Generated by Django 2.1.8 on 2019-04-02 16:39

from django.db import migrations


def forwards(apps, schema_editor):
    pass


class Migration(migrations.Migration):

    dependencies = [("for_runners", "0008_auto_20190402_1731")]

    operations = [migrations.RunPython(forwards, migrations.RunPython.noop)]
