"""
    created 30.05.2018 by Jens Diemer <opensource@jensdiemer.de>
    :copyleft: 2018-2020 by the django-for-runners team, see AUTHORS for more details.
    :license: GNU GPL v3 or above, see LICENSE for more details.
"""

__version__ = "0.12.1"

# https://docs.djangoproject.com/en/2.0/ref/applications/#configuring-applications-ref
default_app_config = "for_runners.apps.ForRunnersConfig"
